==> jc-1.4.0.tar.gz: javax/swing/border/CompoundBorder.h <==
// public class javax.swing.border.CompoundBorder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class 1ae7598b6e002d76 javax_swing_border_CompoundBorder

// header file dependencies
// @dep_header javax_swing_border_AbstractBorder

#include "javax/swing/border/AbstractBorder.h"

#ifndef _JC_javax_swing_border_CompoundBorder_H_
#define _JC_javax_swing_border_CompoundBorder_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_border_Border$object;

// Typedefs
typedef struct _jc_javax_swing_border_CompoundBorder$sub_refs	_jc_javax_swing_border_CompoundBorder$sub_refs;
typedef struct _jc_javax_swing_border_CompoundBorder$sub_nonrefs	_jc_javax_swing_border_CompoundBorder$sub_nonrefs;
typedef struct _jc_javax_swing_border_CompoundBorder$refs	_jc_javax_swing_border_CompoundBorder$refs;
typedef struct _jc_javax_swing_border_CompoundBorder$nonrefs	_jc_javax_swing_border_CompoundBorder$nonrefs;
typedef struct _jc_javax_swing_border_CompoundBorder$object	_jc_javax_swing_border_CompoundBorder$object;

typedef struct _jc_javax_swing_border_CompoundBorder$fields_struct	_jc_javax_swing_border_CompoundBorder$fields_struct;
typedef const struct _jc_javax_swing_border_CompoundBorder$vmethods	_jc_javax_swing_border_CompoundBorder$vmethods;
typedef const struct _jc_javax_swing_border_CompoundBorder$vtable	_jc_javax_swing_border_CompoundBorder$vtable;
typedef const struct _jc_javax_swing_border_CompoundBorder$vtype	_jc_javax_swing_border_CompoundBorder$vtype;

// Class fields structure
struct _jc_javax_swing_border_CompoundBorder$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_border_CompoundBorder$fields_struct _jc_javax_swing_border_CompoundBorder$class_fields;

// Constructors
extern void _jc_javax_swing_border_CompoundBorder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *);
extern void _jc_javax_swing_border_CompoundBorder$method$_init$eb6e1e351633cb7f(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_CompoundBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *, struct _jc_java_awt_Component$object *);
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_CompoundBorder$method$getBorderInsets$8c7185b35170132d(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *);
extern struct _jc_object *_jc_javax_swing_border_CompoundBorder$method$getInsideBorder$869dbbb0d27af419(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *);
extern struct _jc_object *_jc_javax_swing_border_CompoundBorder$method$getOutsideBorder$b8ddf13d638a649e(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *);
extern jboolean _jc_javax_swing_border_CompoundBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *);
extern void _jc_javax_swing_border_CompoundBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_border_CompoundBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_border_CompoundBorder$method_info$getBorderInsets$8c7185b35170132d;
extern _jc_method _jc_javax_swing_border_CompoundBorder$method_info$getInsideBorder$869dbbb0d27af419;
extern _jc_method _jc_javax_swing_border_CompoundBorder$method_info$getOutsideBorder$b8ddf13d638a649e;
extern _jc_method _jc_javax_swing_border_CompoundBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_border_CompoundBorder$method_info$paintBorder$4a79b2eae89db578;

// Virtual methods structure
struct _jc_javax_swing_border_CompoundBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *, struct _jc_java_awt_Component$object *);
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$8c7185b35170132d)(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *);
	struct _jc_object	*(*getInsideBorder$869dbbb0d27af419)(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *);
	struct _jc_object	*(*getOutsideBorder$b8ddf13d638a649e)(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *);
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *);
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_border_CompoundBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_CompoundBorder$vmethods	javax_swing_border_CompoundBorder;
};

// Vtype
struct _jc_javax_swing_border_CompoundBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_border_CompoundBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_border_CompoundBorder$sub_refs {
	struct _jc_object	*insideBorder;
	struct _jc_object	*outsideBorder;
};

// Reference instance fields (object)
struct _jc_javax_swing_border_CompoundBorder$refs {
    _jc_javax_swing_border_CompoundBorder$sub_refs	javax_swing_border_CompoundBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_border_CompoundBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_border_CompoundBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_CompoundBorder$sub_nonrefs	javax_swing_border_CompoundBorder;
};

// Object instance structure
struct _jc_javax_swing_border_CompoundBorder$object {
	_jc_javax_swing_border_CompoundBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_border_CompoundBorder$vtype	*vtype;
	_jc_javax_swing_border_CompoundBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_border_CompoundBorder$vtype _jc_javax_swing_border_CompoundBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_border_CompoundBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_border_CompoundBorder$class_object;

#endif	/* _JC_javax_swing_border_CompoundBorder_H_ */

==> jc-1.4.6.tar.gz: javax/swing/border/CompoundBorder.h <==
// public class javax.swing.border.CompoundBorder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class 1ae7598b6e002d76 javax_swing_border_CompoundBorder

// header file dependencies
// @dep_header javax_swing_border_AbstractBorder

#include "javax/swing/border/AbstractBorder.h"

#ifndef _JC_javax_swing_border_CompoundBorder_H_
#define _JC_javax_swing_border_CompoundBorder_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_border_Border$object;

// Typedefs
typedef struct _jc_javax_swing_border_CompoundBorder$sub_refs	_jc_javax_swing_border_CompoundBorder$sub_refs;
typedef struct _jc_javax_swing_border_CompoundBorder$sub_nonrefs	_jc_javax_swing_border_CompoundBorder$sub_nonrefs;
typedef struct _jc_javax_swing_border_CompoundBorder$refs	_jc_javax_swing_border_CompoundBorder$refs;
typedef struct _jc_javax_swing_border_CompoundBorder$nonrefs	_jc_javax_swing_border_CompoundBorder$nonrefs;
typedef struct _jc_javax_swing_border_CompoundBorder$object	_jc_javax_swing_border_CompoundBorder$object;

typedef struct _jc_javax_swing_border_CompoundBorder$fields_struct	_jc_javax_swing_border_CompoundBorder$fields_struct;
typedef const struct _jc_javax_swing_border_CompoundBorder$vmethods	_jc_javax_swing_border_CompoundBorder$vmethods;
typedef const struct _jc_javax_swing_border_CompoundBorder$vtable	_jc_javax_swing_border_CompoundBorder$vtable;
typedef const struct _jc_javax_swing_border_CompoundBorder$vtype	_jc_javax_swing_border_CompoundBorder$vtype;

// Class fields structure
struct _jc_javax_swing_border_CompoundBorder$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_border_CompoundBorder$fields_struct _jc_javax_swing_border_CompoundBorder$class_fields;

// Constructors
extern void _jc_javax_swing_border_CompoundBorder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_border_CompoundBorder$method$_init$eb6e1e351633cb7f(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_CompoundBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_CompoundBorder$method$getBorderInsets$8c7185b35170132d(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_border_CompoundBorder$method$getInsideBorder$869dbbb0d27af419(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_border_CompoundBorder$method$getOutsideBorder$b8ddf13d638a649e(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_border_CompoundBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_border_CompoundBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_border_CompoundBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_border_CompoundBorder$method_info$getBorderInsets$8c7185b35170132d;
extern _jc_method _jc_javax_swing_border_CompoundBorder$method_info$getInsideBorder$869dbbb0d27af419;
extern _jc_method _jc_javax_swing_border_CompoundBorder$method_info$getOutsideBorder$b8ddf13d638a649e;
extern _jc_method _jc_javax_swing_border_CompoundBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_border_CompoundBorder$method_info$paintBorder$4a79b2eae89db578;

// Virtual methods structure
struct _jc_javax_swing_border_CompoundBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$8c7185b35170132d)(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getInsideBorder$869dbbb0d27af419)(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getOutsideBorder$b8ddf13d638a649e)(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *) _JC_JCNI_ATTR;
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *) _JC_JCNI_ATTR;
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_border_CompoundBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_border_CompoundBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_CompoundBorder$vmethods	javax_swing_border_CompoundBorder;
};

// Vtype
struct _jc_javax_swing_border_CompoundBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_border_CompoundBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_border_CompoundBorder$sub_refs {
	struct _jc_object	*insideBorder;
	struct _jc_object	*outsideBorder;
};

// Reference instance fields (object)
struct _jc_javax_swing_border_CompoundBorder$refs {
    _jc_javax_swing_border_CompoundBorder$sub_refs	javax_swing_border_CompoundBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_border_CompoundBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_border_CompoundBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_CompoundBorder$sub_nonrefs	javax_swing_border_CompoundBorder;
};

// Object instance structure
struct _jc_javax_swing_border_CompoundBorder$object {
	_jc_javax_swing_border_CompoundBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_border_CompoundBorder$vtype	*vtype;
	_jc_javax_swing_border_CompoundBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_border_CompoundBorder$vtype _jc_javax_swing_border_CompoundBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_border_CompoundBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_border_CompoundBorder$class_object;

#endif	/* _JC_javax_swing_border_CompoundBorder_H_ */
